package Bundle::Compress;

use strict;
use warnings;

our $VERSION = '0.01';



1;
__END__


=head1 NAME

Bundle::Compress - installs Compress modules and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Compress'

=head1 CONTENTS

XSLoader

Data::Dumper

List::Util

Text::Unidecode

Text::Wrap

Scalar::Util

Getopt::Long

Pod::Escapes

Pod::Man

Pod::Usage

File::Spec

Test::Harness

Test::Simple

Test::More

Error

Cwd

Devel::Symdump

Class::Inner

File::Slurp

File::Find::Rule

Config::Tiny

Params::Util

Class::Autouse

Algorithm::Dependency

File::Flat

Test::ClassAPI

Class::Inspector

Pod::Tests

IO

IO::Handle

Test::Inline

IO::Compress::Base

IO::Compress::Base::Common

IO::Uncompress::Base

IO::Compress::Gzip

IO::Compress::Gzip::Constants

IO::Uncompress::Gunzip

Compress::Raw::Zlib

Compress::Zlib

File::Path

File::Temp

Config

Time::Local

IO::Zlib

Algorithm::Diff

Text::Diff

Archive::Zip

Archive::Tar

IO::String

Carp

prefork

File::Copy::Recursive

File::Remove

Archive::Builder

Sub::Uplevel

Test::Builder

Text::Wrap

Pod::Simple

Test::Pod

HTML::Tree

Tree::DAG_Node

Test::Exception

Array::Compare

Test::Warn

File::MMagic

MIME::Types

Module::Find

Archive::Any

Archive::Ipkg

Class::MethodMaker

AutoLoader

MIME::Base64

Digest

Digest::SHA

Digest::SHA1

Digest::SHA::PurePerl

Crypt::CBC

Crypt::Twofish

Crypt::Blowfish  

Crypt::RIPEMD160

Test::Manifest

Crypt::Rijndael

Crypt::DES

Crypt::DES_EDE3

Digest::MD5

Crypt::IDEA

Data::Buffer

Class::Loader

Digest::MD2

Sort::Versions

Convert::ASCII::Armour

Tie::EncryptedHash

Data::Dumper

Crypt::Random

Crypt::Primes

Crypt::RSA

Data::Buffer

Class:ErrorHandler

Convert::ASN1

Convert::PEM

Data::Random

bignum

Math::BigRat

Math::BigInt

Math::BigInt::GMP

Math::BigInt::FastCalc

Crypt::DSA

URI

HTML::Parser

LWP::UserAgent

Crypt::OpenPGP

PAR

PAR::Dist

Archive::Ipkg

IO::Tty

Log::Info

IPC::Run

Archive::Par

IO::Stringy

Archive::SelfExtract

Archive::Tar::Streamed

UNIVERSAL::can

UNIVERSAL::isa

Archive::Ar

Locale::Maketext::Simple

Module::Load::Conditional

Params::Check

IPC::Cmd

Archive::Extract

Term::ReadKey

Crypt::CipherSaber

Archive::Tyd

XML::SAX

XML::NamespaceSupport

XML::LibXML

XML::LibXML::Common

RPC::XML::Parser

XML::SAX::Expat::Incremental

XML::Parser

XML::Parser::Expat

Heap

Math::Complex

XML::DOM

Log::Log4perl

Archive::Tar::Wrapper

Archive::Cpio

Archive::StringToZip

Archive::Rar

Test::STDmaker

Tie::Layers

Tie::Form

Text::Scrub

Text::Column

Text::Replace

File::Maker

ExtUtils::SVDmaker

PerlIO::gzip

File::SmartNL

File::Where

File::Package

Data::Startup

File::AnySpec

Tie::Gzip

Archive::TarGzip

Archive::ZZip

Compress::Bzip2

Devel::Peek

Time::HiRes

Time::TAI64

YAML

Devel::Size

Devel::Size::Report

Test::Builder::Tester

Hook::LexWrap

Attribute::Handlers

Devel::Caller

Devel::LexAlias

PadWalker

Devel::Cycle

Test::Memory::Cycle

Compress::LZW::Progressive

Compress::unLZMA

Sub::Install

Data::OptList

Sub::Exporter

List::MoreUtils

Number::Nary

Compress::AsciiFlate

Compress::LZO

Compress::LZW

Compress::LZF

Compress::LZV1

Compress::Zlib::Perl

Compress::Raw::Bzip2

Compress::PPMd

Text::Balanced

Compress::SelfExtracting

Compress::LeadingBlankSpaces

version

Text::ParseWords

Test

ExtUtils::CBuilder

Class::Std::Utils

Compress::BraceExpansion

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

1;
